@@ -15,7 +15,7 @@ Readonly::Array our @EXPORT_OK => qw(first_male first_female middle_female
 	last_male last_female middle_male middle_female name);
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # First and middle male names.
 our @first_male = our @middle_male = qw(
@@ -210,7 +210,7 @@ Zlatko
 Zoltán
 );
 
-# First nad middle female names.
+# First and middle female names.
 our @first_female = our @middle_female = qw(
 Adela
 Adriána
@@ -2130,13 +2130,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Mock::Person>,
-L<Mock::Person::CZ>,
-L<Mock::Person::EN>,
-L<Mock::Person::DE>,
-L<Mock::Person::SK::ROM>,
-L<Mock::Person::SV>,
-L<Mock::Person::RU>.
+=over
+
+=item L<Task::Mock::Person>
+
+Install the Mock::Person modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -2150,10 +2150,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © Michal Špaček 2013-2015
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
